@@ -1,19 +1,15 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2011-2017 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2011-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 """Adds default data for `CoachingEnding`.
 
 """
 
-from __future__ import unicode_literals
-
-from django.utils.translation import gettext_lazy as _
-
 from lino.api.dd import babelkw
+from lino.api import rt, _
 
 
 def objects():
-    from lino.api import rt
     CoachingEnding = rt.models.coachings.CoachingEnding
 
     yield CoachingEnding(**babelkw('name',
@@ -32,4 +28,3 @@ def objects():
                                    de="Hat selber Arbeit gefunden",
                                    fr="A trouvé du travail",
                                    en="Found a job"))
-    
