@@ -729,7 +729,7 @@ class Role(dd.Model, Addressable):
         # needed to activate create_person_choice
         return rt.models.contacts.Person.objects.all()
 
-    def create_person_choice(self, text):
+    def create_person_choice(self, text, ar=None):
         return rt.models.contacts.Person.create_from_choice(text)
 
 
