@@ -1,10 +1,6 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2017-2018 Rumma & Ko Ltd
+# Copyright 2017-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
-"""Model mixins for this plugin.
-"""
-from builtins import object
-from builtins import str
 
 from django.db.models import Q
 
@@ -12,12 +8,11 @@ from lino.api import dd, _
 from .choicelists import EnrolmentStates
 
 
-
 class Enrollable(dd.Model):
-    
+
     class Meta(object):
         abstract = True
-    
+
     def __str__(self):
         s = self.get_full_name(salutation=False)
         info = self.get_enrolment_info()
@@ -31,7 +26,7 @@ class Enrollable(dd.Model):
 
         """
         return None
-    
+
     @classmethod
     def setup_parameters(cls, fields):
         fields.update(
@@ -81,4 +76,3 @@ class Enrollable(dd.Model):
             yield str(pv.course)
         if pv.enrolment_state:
             yield str(pv.enrolment_state)
-
