@@ -71,6 +71,7 @@ class Slot(mixins.Sequenced, StartEndTime):
         app_label = 'courses'
         verbose_name = _("Timetable Slot")  # Zeitnische
         verbose_name_plural = _('Timetable Slots')
+        abstract = dd.is_abstract_model(__name__, 'Slot')
 
     name = models.CharField(max_length=200,
                             blank=True,
@@ -576,13 +577,13 @@ class Enrolment(UserAuthored, Certifiable, DateRange):
         Pupil = dd.resolve_model(pupil_model)
         return Pupil.objects.all()
 
-    def create_pupil_choice(self, text):
+    def create_pupil_choice(self, text, ar=None):
         """
         Called when an unknown pupil name was given.
         Try to auto-create it.
         """
 
-    def create_pupil_choice(self, text):
+    def create_pupil_choice(self, text, ar=None):
         Pupil = dd.resolve_model(pupil_model)
         return Pupil.create_from_choice(text)
 
