@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2016-2019 Rumma & Ko Ltd
+# Copyright 2016-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
@@ -12,6 +12,7 @@ See :doc:`/plugins/invoicing`.
 
 from lino.api.ad import Plugin, _
 from django.utils.text import format_lazy
+from django.utils.module_loading import import_string
 
 
 class Plugin(Plugin):
@@ -28,6 +29,7 @@ class Plugin(Plugin):
     In Presto and Noi this is 'orders.Order'.
     """
 
+    # default_voucher_view = 'lino_xl.lib.sales.ui.InvoicesByJournal'
     voucher_model = 'sales.VatProductInvoice'
     item_model = 'sales.InvoiceItem'
     """
@@ -48,6 +50,15 @@ class Plugin(Plugin):
     instead of one.
     """
 
+    delivery_notes_demo = False
+    """
+    Whether the :fixture:`demo` fixtures should generate delivery notes.
+    """
+
+    # def on_site_startup(self, site):
+    #     super().on_site_startup(site)
+    #     self.default_voucher_view = import_string(self.default_voucher_view)
+
     def before_analyze(self):
         # print("20210722 before_analyze()")
         from lino.core.utils import resolve_model
@@ -57,6 +68,7 @@ class Plugin(Plugin):
         #     raise Exception("voucher_model is {} but should be {}".format(
         #         self.voucher_model, ivm))
         self.voucher_model = resolve_model(self.voucher_model)
+        # assert issubclass(self.default_voucher_view, dbtables.Table)
         if self.order_model is not None:
             self.order_model = resolve_model(self.order_model)
 
@@ -64,8 +76,14 @@ class Plugin(Plugin):
         # from lino.core.utils import resolve_model
         # model = resolve_model(self.voucher_model)
         # return self.site.modules.ledger.VoucherTypes.get_for_model(model)
-        return self.site.models.ledger.VoucherTypes.get_for_model(
-            self.voucher_model)
+        # return self.site.models.ledger.VoucherTypes.get_for_model(
+        #     self.voucher_model)
+        for i in self.site.models.ledger.VoucherTypes.get_list_items():
+            if issubclass(i.model, self.voucher_model):
+                return i
+        raise Exception("20220512 No voucher type for %s" % self.voucher_model)
+        # return self.site.models.ledger.VoucherTypes.get_for_model(
+        #     self.voucher_model)
 
     def setup_main_menu(config, site, user_type, m):
         mg = site.plugins.sales
@@ -86,6 +104,7 @@ class Plugin(Plugin):
         mg = site.plugins.sales
         m = m.add_menu(mg.app_label, mg.verbose_name)
         m.add_action('invoicing.Tariffs')
+        m.add_action('invoicing.FollowUpRules')
         m.add_action('invoicing.Areas')
 
     def setup_explorer_menu(self, site, user_type, m):
