@@ -1,8 +1,7 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2016-2021 Rumma & Ko Ltd
+# Copyright 2016-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
-
 from django.db import models
 from django.conf import settings
 from django.utils.text import format_lazy
@@ -23,6 +22,7 @@ from lino.utils import ONE_DAY
 from lino.api import dd, rt, _
 from lino_xl.lib.ledger.utils import ZERO
 from lino_xl.lib.ledger.roles import LedgerUser, LedgerStaff
+from lino_xl.lib.ledger.mixins import JournalRef
 # from lino_xl.lib.cal.choicelists import DurationUnits
 
 from .mixins import InvoiceGenerator
@@ -44,6 +44,29 @@ generator_label = _("Generator")
 #     order_model = None
 #
 
+class FollowUpRule(Sequenced):
+
+    class Meta:
+        app_label = 'invoicing'
+        verbose_name = _("Follow-up rule")
+        verbose_name_plural = _("Follow-up rules")
+
+    source_journal = dd.ForeignKey(
+        'ledger.Journal', related_name="followup_source")
+    target_journal = dd.ForeignKey(
+        'ledger.Journal', related_name="followup_target")
+    # from_state = InvoicingState.field()
+    # to_state = InvoicingState.field()
+
+    allow_cascaded_delete = "source_journal target_journal"
+
+
+class FollowUpRules(dd.Table):
+    model = 'invoicing.FollowUpRule'
+    # required_roles = dd.login_required(LedgerStaff)
+    column_names = 'source_journal target_journal *'
+
+
 class SalesRule(dd.Model):
     class Meta:
         app_label = 'invoicing'
@@ -245,6 +268,7 @@ class Plan(UserPlan):
         max_date = self.get_max_date()
         for ig in self.get_generators_for_plan():
             partner = ig.get_invoiceable_partner()
+            # print("20220507 partner", partner)
             if partner is None:
                 continue
                 # raise Exception("{!r} has no invoice recipient".format(
@@ -262,7 +286,7 @@ class Plan(UserPlan):
 
             invoice_items = list(ig.get_invoice_items(info, invoice, ar))
             if len(invoice_items) == 0:
-                # dd.logger.debug("20181126 no invoice items for %s", ig)
+                # dd.logger.info("20181126 no invoice items for %s", ig)
                 continue
 
             # print("20210731", partner, invoice_items)
@@ -317,7 +341,8 @@ class Plan(UserPlan):
 
     def create_invoice(self, **kwargs):
         # ITEM_MODEL = dd.plugins.invoicing.item_model
-        M = dd.plugins.invoicing.voucher_model
+        # M = dd.plugins.invoicing.default_voucher_view.model
+        M = self.area.journal.voucher_type.model
         # M = ITEM_MODEL._meta.get_field('voucher').remote_field.model
         kwargs.update(
             journal=self.area.journal,
@@ -515,11 +540,12 @@ dd.inject_field(
     'products.Product', 'tariff', dd.ForeignKey(
         'invoicing.Tariff', blank=True, null=True))
 
+VOUCHER_MODEL = dd.plugins.invoicing.voucher_model
 dd.inject_field(
-    dd.plugins.invoicing.voucher_model, 'invoicing_min_date', dd.DateField(
+    VOUCHER_MODEL, 'invoicing_min_date', dd.DateField(
         _("Invoiceables from"), blank=True, null=True))
 dd.inject_field(
-    dd.plugins.invoicing.voucher_model, 'invoicing_max_date', dd.DateField(
+    VOUCHER_MODEL, 'invoicing_max_date', dd.DateField(
         _("until"), blank=True, null=True))
 
 dd.inject_field(
