@@ -263,8 +263,7 @@ class VoucherTypes(dd.ChoiceList):
 
     @classmethod
     def find_unique(cls, func, default=None):
-
-        """Find the unique item which matches the condition. Return default if
+        """Find the unique item that matches the condition. Return default if
         no item or more than one item matches."""
         candidates = set()
         for o in cls.get_list_items():
