@@ -20,12 +20,14 @@ def objects():
 
     JournalGroups = rt.models.ledger.JournalGroups
     Company = rt.models.contacts.Company
+    PaymentMethod = rt.models.ledger.PaymentMethod
 
     # JOURNALS
 
     kw = dict(journal_group=JournalGroups.sales)
     if sales:
-        MODEL = sales.VatProductInvoice
+        # MODEL = sales.VatProductInvoice
+        MODEL = sales.InvoicesByJournal
     else:
         MODEL = vat.VatAccountInvoice
     kw.update(trade_type='sales')
@@ -42,6 +44,23 @@ def objects():
     SLS_JOURNAL = MODEL.create_journal(**kw)
     yield SLS_JOURNAL
 
+    if dd.is_installed('invoicing') and dd.plugins.invoicing.delivery_notes_demo:
+        kw.update(ref="SDN", dc=DC.credit)
+        kw.update(dd.str2kw('printed_name', _("Delivery note")))
+        kw.update(dd.str2kw('name', _("Delivery notes")))
+        kw.update(make_ledger_movements=False)
+        misc_partner = rt.models.contacts.Company(
+            name="Miscellaneous",
+            country=dd.plugins.countries.get_my_country())
+        yield misc_partner
+        kw.update(partner=misc_partner)
+        SDN_JOURNAL = sales.SalesNotesByJournal.create_journal(**kw)
+        yield SDN_JOURNAL
+        yield PaymentMethod(designation=_("Cash payment"), journal=SDN_JOURNAL)
+        yield rt.models.invoicing.FollowUpRule(
+            source_journal=SDN_JOURNAL,
+            target_journal=SLS_JOURNAL)
+
     if dd.plugins.vat.declaration_plugin is None:
         dd.logger.warning("No journal SLC, BNK, PMO etc because declaration_plugin is None")
         return
