@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2008-2021 Rumma & Ko Ltd
+# Copyright 2008-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import datetime
@@ -74,7 +74,7 @@ class Journal(BabelNamed, Sequenced, Referrable, PrintableType):
     force_sequence = models.BooleanField(
         _("Force chronological sequence"), default=False)
     preliminary = models.BooleanField(_("Preliminary"), default=False)
-
+    make_ledger_movements = models.BooleanField(_("Ledger"), default=True)
     account = dd.ForeignKey('ledger.Account', blank=True, null=True)
     partner = dd.ForeignKey('contacts.Company', blank=True, null=True)
     printed_name = dd.BabelCharField(
@@ -1183,7 +1183,10 @@ class VoucherChecker(Checker):
                     m.seqno = seqno
                     # if fcu and m.value_date <= fcu:
                     #     m.cleared = True
-                    m.full_clean()
+                    try:
+                        m.full_clean()
+                    except ValidationError as e:
+                        raise Exception("{} in {}".format(e, m))
                     wanted[m2k(m)] = m
             except Warning as e:
                 yield (False, self.messages['warning'].format(obj, e))
