@@ -40,7 +40,7 @@ class JournalDetail(dd.DetailLayout):
     name ref:5
     journal_group:15 voucher_type:20 trade_type:20 seqno:5 id:5
     account partner build_method:20 template:20 uploads_volume
-    dc force_sequence #invert_due_dc yearly_numbering auto_fill_suggestions auto_check_clearings must_declare preliminary
+    dc force_sequence yearly_numbering auto_fill_suggestions make_ledger_movements auto_check_clearings must_declare preliminary
     printed_name
     MatchRulesByJournal
     """
