@@ -189,7 +189,7 @@ class Pages(dd.Table):
 
 
 class PublicPages(Pages):
-    display_mode = constants.DISPLAY_MODE_STORY
+    display_mode_main = constants.DISPLAY_MODE_STORY
 
 
 #~ class MyPages(ByUser,Pages):
