@@ -62,7 +62,7 @@ class Product(BabelNamed, BabelPreviewable, Duplicable):
         abstract = dd.is_abstract_model(__name__, 'Product')
 
     category = dd.ForeignKey(
-        Category, verbose_name=_("Category"),
+        'products.Category', verbose_name=_("Category"),
         blank=True, null=True)
     delivery_unit = DeliveryUnits.field(default='piece')
     product_type = ProductTypes.field()
