@@ -44,7 +44,10 @@ def objects():
     if not dd.plugins.ledger.sales_stories:
         return
     PRODUCTS = Cycler(Product.objects.order_by('id'))
-    JOURNAL_S = Journal.objects.get(ref="SLS")
+    if dd.is_installed('invoicing') and dd.plugins.invoicing.delivery_notes_demo:
+        JOURNAL_S = Journal.objects.get(ref="SDN")
+    else:
+        JOURNAL_S = Journal.objects.get(ref="SLS")
 
 
     # tt = TradeTypes.sales
