@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2018-2020 Rumma & Ko Ltd
+# Copyright 2018-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 # import datetime
 
@@ -43,6 +43,8 @@ class Item(StructuredReferrable, BabelDesignated):
     mirror_ref = models.CharField(
         _("Mirror"), max_length=ref_max_length, blank=True, null=True)
 
+Item.set_widget_options('dc', preferred_width=20)
+
 
 class Collector(object):
     def __init__(self, entry_model, fkname, outer_link, **rowmvtfilter):
@@ -483,6 +485,11 @@ class Items(dd.Table):
     model = 'sheets.Item'
     order_by = ['ref']
     column_names = "ref designation sheet_type dc common_item *"
+    insert_layout = """
+    designation
+    ref sheet_type
+    dc common_item
+    """
 
 
 class AccountEntries(dd.Table):
