@@ -146,7 +146,7 @@ class DemandsByDemander(Demands):
     importance
     """
 
-    display_mode = 'summary'
+    display_mode_main = 'summary'
     
     @classmethod
     def get_table_summary(self, obj, ar):
@@ -177,7 +177,7 @@ class OffersByDemander(Offers):
     master = dd.plugins.skills.demander_model
     column_names = '*'
     order_by = ["affinity"]
-    display_mode = 'summary'
+    display_mode_main = 'summary'
     
 
     @classmethod
