@@ -749,8 +749,13 @@ if dd.is_installed('vat'):
                             # TODO: compare the name
                             return
                     except pyvat.exceptions.ServerError as e:
-                        dd.logger.info("pyvat.check_vat_number('%s', '%s') failed:", self.vn, self.country_code)
-                        dd.logger.info("  " + ("\n  ".join(result.log_lines)))
+                        dd.logger.info(
+                            "pyvat.check_vat_number('%s', '%s') failed with {}:",
+                            self.vn, self.country_code, e)
+                        if result is None:
+                            dd.logger.info("   (no response)")
+                        else:
+                            dd.logger.info("  " + ("\n  ".join(result.log_lines)))
                         if attempts > MAX_ONLINE_ATTEMPTS:
                             raise ValidationError(str(e))
                         time.sleep(1)
