@@ -279,7 +279,7 @@ class AllVotes(Votes):
 #     label = _("Votes")
 #     master_key = 'project'
 #     column_names = 'votable user workflow_buttons *'
-#     display_mode = 'summary'
+#     display_mode_main = 'summary'
 #     stay_in_grid = True
 
 
@@ -343,7 +343,7 @@ class VotesByVotable(Votes):
     column_names = 'user workflow_buttons mail_mode *'
     # show_detail_navigator = False
     # hide_top_toolbar = True
-    display_mode = 'summary'
+    display_mode_main = 'summary'
     # exclude_vote_states = 'author'
     stay_in_grid = True
 
